@@ -7,9 +7,27 @@ Released under GNU GPL version 3 or later
 '''
 
 import socket, math, struct, time, os, fnmatch, array, sys, errno
+
+# adding these extra imports allows pymavlink to be used directly with pyinstaller
+# without having complex spec files
+import json
+from pymavlink.dialects.v10 import ardupilotmega
+
+# these imports allow for mavgraph and mavlogdump to use maths expressions more easily
 from math import *
 from mavextra import *
 
+'''
+Support having a $HOME/.pymavlink/mavextra.py for extra graphing functions
+'''
+home = os.getenv('HOME')
+if home is not None:
+    extra = os.path.join(home, '.pymavlink', 'mavextra.py')
+    if os.path.exists(extra):
+        import imp
+        mavuser = imp.load_source('pymavlink.mavuser', extra)
+        from pymavlink.mavuser import *
+
 mavlink = None
 
 def mavlink10():
@@ -418,7 +436,7 @@ class mavfile(object):
             map = mode_mapping_rover
         if map is None:
             return None
-        inv_map = {a:b for b, a in map.items()}
+        inv_map = dict((a, b) for (b, a) in map.items())
         return inv_map
 
     def set_mode(self, mode):
@@ -920,16 +938,23 @@ def mavlink_connection(device, baud=115200, source_system=255,
         return mavtcp(device[4:], source_system=source_system)
     if device.startswith('udp:'):
         return mavudp(device[4:], input=input, source_system=source_system)
+
     if device.endswith('.bin'):
         # support dataflash logs
         from pymavlink import DFReader
-        return DFReader.DFReader_binary(device)
+        m = DFReader.DFReader_binary(device)
+        global mavfile_global
+        mavfile_global = m
+        return m
+
     if device.endswith('.log'):
         # support dataflash text logs
         from pymavlink import DFReader
         if DFReader.DFReader_is_text_log(device):
-            return DFReader.DFReader_text(device)
-    
+            global mavfile_global
+            m = DFReader.DFReader_text(device)
+            mavfile_global = m
+            return m    
 
     # list of suffixes to prevent setting DOS paths as UDP sockets
     logsuffixes = [ 'log', 'raw', 'tlog' ]
@@ -1163,6 +1188,12 @@ def mode_string_apm(mode_number):
     if mode_number in mode_mapping_apm:
         return mode_mapping_apm[mode_number]
     return "Mode(%u)" % mode_number
+
+def mode_string_acm(mode_number):
+    '''return mode string for APM:Copter'''
+    if mode_number in mode_mapping_acm:
+        return mode_mapping_acm[mode_number]
+    return "Mode(%u)" % mode_number
     
 
 class x25crc(object):
